@@ -15,7 +15,7 @@ from .configuration.discovery import get_configuration_medium, load_cwd_workspac
 from .configuration.shared import HOST_REGEX, PATH_REGEX
 from .exceptions import InvalidInputError, RemoteError
 from .explain import explain
-from .util import CommunicationOptions, ForwardingOptions
+from .util import CommunicationOptions, ForwardingOption
 from .workspace import SyncedWorkspace
 
 BASE_LOGGING_FORMAT = "%(message)s"
@@ -234,6 +234,7 @@ def remote_set(index: int):
     "--tunnel",
     "port_args",
     type=str,
+    multiple=True,
     help="Enable local port forwarding. Pass value as <remote port>:<local port>. \
 If local port is not passed, the local port value would be set to <remote port> value by default",
 )
@@ -260,7 +261,7 @@ def remote(
     mirror: bool,
     verbose: bool,
     e: bool,
-    port_args: Optional[str],
+    port_args: List[str],
     label: Optional[str],
     stream_changes: bool,
     log: Optional[str],
@@ -272,7 +273,7 @@ def remote(
     if verbose:
         logging.basicConfig(level=logging.INFO, format=BASE_LOGGING_FORMAT)
 
-    ports = ForwardingOptions.from_string(port_args) if port_args else None
+    ports = [ForwardingOption.from_string(port_arg) for port_arg in port_args]
 
     if multi and label:
         raise InvalidInputError("--multi and --label options cannot be used together")
@@ -294,7 +295,10 @@ def remote(
                     # If the logs are enabled and they are inside the workspace root, we need to exclude them from
                     # syncing
                     relative_path = log_dir.relative_to(workspace.local_root)
-                    workspace.ignores.add([f"{relative_path}/*_output.log"])
+
+                    log_path = f"{relative_path}/*_output.log"
+                    workspace.pull_rules.excludes.append(log_path)
+                    workspace.push_rules.excludes.append(log_path)
                 except ValueError:
                     # Value error means that logs are placed outside of the workspace root
                     pass
@@ -333,15 +337,28 @@ def remote(
 
 
 @click.command(context_settings=EXECUTION_CONTEXT_SETTINGS)
+@click.option(
+    "-t",
+    "--tunnel",
+    "port_args",
+    type=str,
+    multiple=True,
+    help="Enable local port forwarding. Pass value as <remote port>:<local port>. \
+If local port is not passed, the local port value would be set to <remote port> value by default",
+)
 @click.option("-l", "--label", help="use the host that has corresponding label for the remote execution")
 @click.argument("command", nargs=-1, required=True)
 @log_exceptions
-def remote_quick(command: List[str], label: Optional[str]):
-    """Execute the COMMAND remotely"""
+def remote_quick(
+    command: List[str], port_args: List[str], label: Optional[str],
+):
+    """Execute the COMMAND remotely, without syncing any files"""
     check_command(command)
 
+    ports = [ForwardingOption.from_string(port_arg) for port_arg in port_args]
+
     workspace = SyncedWorkspace.from_cwd(int_or_str_label(label))
-    code = workspace.execute(command, raise_on_error=False)
+    code = workspace.execute(command, ports=ports, raise_on_error=False)
     sys.exit(code)
 
 
