@@ -7,8 +7,8 @@ import pytest
 
 from remote.configuration import RemoteConfig
 from remote.exceptions import InvalidRemoteHostLabel
-from remote.util import CommunicationOptions, ForwardingOptions
-from remote.workspace import SyncedWorkspace
+from remote.util import CommunicationOptions, ForwardingOption
+from remote.workspace import CompiledSyncRules, SyncedWorkspace
 
 
 def test_create_workspace(workspace_config):
@@ -18,7 +18,8 @@ def test_create_workspace(workspace_config):
     assert workspace.local_root == workspace_config.root
     assert workspace.remote == workspace_config.configurations[0]
     assert workspace.remote_working_dir == workspace_config.configurations[0].directory / "foo" / "bar"
-    assert workspace.ignores == workspace_config.ignores
+    assert workspace.pull_rules == CompiledSyncRules([], [])
+    assert workspace.push_rules == CompiledSyncRules([], ["/.remoteenv"])
 
 
 def test_create_workspace_selects_proper_remote_host(workspace_config):
@@ -45,7 +46,8 @@ def test_create_workspace_selects_proper_remote_host(workspace_config):
     assert workspace.local_root == workspace_config.root
     assert workspace.remote == workspace_config.configurations[1]
     assert workspace.remote_working_dir == workspace_config.configurations[1].directory / "foo" / "bar"
-    assert workspace.ignores == workspace_config.ignores
+    assert workspace.pull_rules == CompiledSyncRules([], [])
+    assert workspace.push_rules == CompiledSyncRules([], ["/.remoteenv"])
     assert workspace.remote.label == "bar"
 
     # now it should select host from override
@@ -53,14 +55,16 @@ def test_create_workspace_selects_proper_remote_host(workspace_config):
     assert workspace.local_root == workspace_config.root
     assert workspace.remote == workspace_config.configurations[0]
     assert workspace.remote_working_dir == workspace_config.configurations[0].directory / "foo" / "bar"
-    assert workspace.ignores == workspace_config.ignores
+    assert workspace.pull_rules == CompiledSyncRules([], [])
+    assert workspace.push_rules == CompiledSyncRules([], ["/.remoteenv"])
 
     # now it should select from the label passed
     workspace = SyncedWorkspace.from_config(workspace_config, working_dir, remote_host_id="foo")
     assert workspace.local_root == workspace_config.root
     assert workspace.remote == workspace_config.configurations[2]
     assert workspace.remote_working_dir == workspace_config.configurations[2].directory / "foo" / "bar"
-    assert workspace.ignores == workspace_config.ignores
+    assert workspace.pull_rules == CompiledSyncRules([], [])
+    assert workspace.push_rules == CompiledSyncRules([], ["/.remoteenv"])
     assert workspace_config.configurations[2].label == "foo"
 
     # now it should raise an exception as the label is not present
@@ -275,7 +279,7 @@ echo 'Hello World!'
 def test_execute_with_port_forwarding(mock_run, workspace):
     mock_run.return_value = MagicMock(returncode=0)
 
-    code = workspace.execute(["echo", "Hello World!"], ports=ForwardingOptions(5005, 5000),)
+    code = workspace.execute(["echo", "Hello World!"], ports=[ForwardingOption(5005, 5000)],)
     mock_run.assert_called_once_with(
         [
             "ssh",
@@ -306,7 +310,7 @@ def test_execute_with_custom_port(mock_run, workspace):
     mock_run.return_value = MagicMock(returncode=0)
 
     workspace.remote.port = 4321
-    code = workspace.execute(["echo", "Hello World!"], ports=ForwardingOptions(5005, 5000, local_interface="0.0.0.0"),)
+    code = workspace.execute(["echo", "Hello World!"], ports=[ForwardingOption(5005, 5000, local_interface="0.0.0.0")],)
     mock_run.assert_called_once_with(
         [
             "ssh",
@@ -435,7 +439,7 @@ echo 'Hello World!'
 def test_execute_and_sync_with_port_forwarding(mock_run, workspace):
     mock_run.side_effect = [MagicMock(returncode=0), MagicMock(returncode=10), MagicMock(returncode=0)]
 
-    code = workspace.execute_in_synced_env(["echo", "Hello World!"], ports=ForwardingOptions(5005, 5000),)
+    code = workspace.execute_in_synced_env(["echo", "Hello World!"], ports=[ForwardingOption(5005, 5000)],)
     mock_run.assert_has_calls(
         [
             call(
